****************
* Replication code for Has the euro paid off? A study of the trade-induced welfare effects of the EMU
**Accepted for publication in Journal of Money, Credit and Banking
*Silviano Esteve-Pérez, Salvador Gil-Pareja, Rafael Llorca-Vivero, and Jordi Paniagua
* jordi.paniagua@uv.es
* Nov 25, 2023
***********************

capture log close
log using "Has the euro paid off", text replace

use "emu_ge_data_rev.dta", replace



****************************************************
*Create pair ID and symmetric pair ID variables*
****************************************************
egen pair_id=group(exporter importer)
gen first = cond(exporter < importer, exporter, importer)
gen second = cond(exporter < importer, importer, exporter)
gen symm = first+"_"+second
egen symm_pair_id = group(symm)

****************************************************
*Create asymmetric pair ID variables*
*create exporter-year and importer_year FE*
****************************************************

egen pairid_asym=group(exporter importer)
egen exp_year=group(exporter year)
egen imp_year=group(importer year)





ren CUEURO2 emu 
ren CUEURO1 emu_ONE


ge custrict11_woemu=custrict11 - emu



ge EU2woemu=EU2-emu
ge EU1woemu_ONE=EU1-emu_ONE



foreach var in rta cu fta eia ps cuandeia ftaandeia emu emu_ONE CU2 CU2_WO_EMU custrict11 custrict11_woemu EU2 EU1 EU2woemu EU1woemu_ONE rta_woEU2  {
replace `var'=0 if exporter==importer
}

ren custrict11_woemu cuwoemu
ren rta_woEU2 regional_woEU
* 
* GENERATE A TREND
* 
ge trend=year

replace trend=1 if year==1986
replace trend=2 if year==1987
replace trend=3 if year==1988 
replace trend=4 if year==1989
replace trend=5 if year==1990
replace trend=6 if year==1991
replace trend=7 if year==1992 
replace trend=8 if year==1993
replace trend=9 if year==1994
replace trend=10 if year==1995
replace trend=11 if year==1996
replace trend=12 if year==1997
replace trend=13 if year==1998
replace trend=14 if year==1999
replace trend=15 if year==2000
replace trend=16 if year==2001
replace trend=17 if year==2002
replace trend=18 if year==2003
replace trend=19 if year==2004
replace trend=20 if year==2005
replace trend=21 if year==2006
replace trend=22 if year==2007
replace trend=23 if year==2008
replace trend=24 if year==2009
replace trend=25 if year==2010
replace trend=26 if year==2011
replace trend=27 if year==2012
replace trend=28 if year==2013
replace trend=29 if year==2014
replace trend=30 if year==2015
replace trend=31 if year==2016 
replace trend=32 if year==2017

* END GENERATION OF A TREND


gen pair_trend=pairid_asym*trend

ge EUtrend=EU2*trend
ge trendsq=trend*trend
ge EUtrendsq=EU2*trendsq



ge year2=0

replace year2=1 if year==1986
replace year2=1 if year==1988
replace year2=1 if year==1990
replace year2=1 if year==1992
replace year2=1 if year==1994
replace year2=1 if year==1996
replace year2=1 if year==1998
replace year2=1 if year==2000
replace year2=1 if year==2002
replace year2=1 if year==2004
replace year2=1 if year==2006
replace year2=1 if year==2008
replace year2=1 if year==2010
replace year2=1 if year==2012
replace year2=1 if year==2014
replace year2=1 if year==2016

ge year3=0
replace year3=1 if year==1986
replace year3=1 if year==1989
replace year3=1 if year==1992
replace year3=1 if year==1995
replace year3=1 if year==1998
replace year3=1 if year==2001
replace year3=1 if year==2004
replace year3=1 if year==2007
replace year3=1 if year==2010
replace year3=1 if year==2013
replace year3=1 if year==2016

ge year5=0
replace year5=1 if year==1986
replace year5=1 if year==1991
replace year5=1 if year==1996
replace year5=1 if year==2001
replace year5=1 if year==2006
replace year5=1 if year==2011
replace year5=1 if year==2016

*********
*International border
***********

gen INTL_BRDR=1 if exporter!=importer
replace INTL_BRDR=0 if INTL_BRDR==.

forvalues i=1986(1)2016{
gen INTL_BRDR_`i'=1 if INTL_BRDR==1 & year==`i'
replace INTL_BRDR_`i'=0 if INTL_BRDR_`i'==.
}
***** 

**********************************************
*EMU X INTL_BDDR per year   *
**********************************************

gen emu1999=emu*INTL_BRDR_1999
gen emu2000=emu*INTL_BRDR_2000
gen emu2001=emu*INTL_BRDR_2001
gen emu2002=emu*INTL_BRDR_2002
gen emu2003=emu*INTL_BRDR_2003
gen emu2004=emu*INTL_BRDR_2004
gen emu2005=emu*INTL_BRDR_2005
gen emu2006=emu*INTL_BRDR_2006
gen emu2007=emu*INTL_BRDR_2007
gen emu2008=emu*INTL_BRDR_2008
gen emu2009=emu*INTL_BRDR_2009
gen emu2010=emu*INTL_BRDR_2010
gen emu2011=emu*INTL_BRDR_2011
gen emu2012=emu*INTL_BRDR_2012
gen emu2013=emu*INTL_BRDR_2013
gen emu2014=emu*INTL_BRDR_2014
gen emu2015=emu*INTL_BRDR_2015
gen emu2016=emu*INTL_BRDR_2016

**********************************************
* emu_ONE X INTL_BDDR per year  *
**********************************************

gen emu_ONE1999=emu_ONE*INTL_BRDR_1999
gen emu_ONE2000=emu_ONE*INTL_BRDR_2000
gen emu_ONE2001=emu_ONE*INTL_BRDR_2001
gen emu_ONE2002=emu_ONE*INTL_BRDR_2002
gen emu_ONE2003=emu_ONE*INTL_BRDR_2003
gen emu_ONE2004=emu_ONE*INTL_BRDR_2004
gen emu_ONE2005=emu_ONE*INTL_BRDR_2005
gen emu_ONE2006=emu_ONE*INTL_BRDR_2006
gen emu_ONE2007=emu_ONE*INTL_BRDR_2007
gen emu_ONE2008=emu_ONE*INTL_BRDR_2008
gen emu_ONE2009=emu_ONE*INTL_BRDR_2009
gen emu_ONE2010=emu_ONE*INTL_BRDR_2010
gen emu_ONE2011=emu_ONE*INTL_BRDR_2011
gen emu_ONE2012=emu_ONE*INTL_BRDR_2012
gen emu_ONE2013=emu_ONE*INTL_BRDR_2013
gen emu_ONE2014=emu_ONE*INTL_BRDR_2014
gen emu_ONE2015=emu_ONE*INTL_BRDR_2015
gen emu_ONE2016=emu_ONE*INTL_BRDR_2016


******
*Two periods
*****

gen emu_ONE1999_07=emu_ONE1999+emu_ONE2000+emu_ONE2001+emu_ONE2002+emu_ONE2003+emu_ONE2004+emu_ONE2005+emu_ONE2006+emu_ONE2007

gen emu_ONE2008_16=emu_ONE2008+emu_ONE2009+emu_ONE2010+emu_ONE2011+emu_ONE2012+emu_ONE2013+emu_ONE2014+emu_ONE2015+emu_ONE2016


gen emu1999_07=emu1999+emu2000+emu2001+emu2002+emu2003+emu2004+emu2005+emu2006+emu2007
gen emu2008_16=emu2008+emu2009+emu2010+emu2011+emu2012+emu2013+emu2014+emu2015+emu2016

*********************
*Table 1
*********************



* Table 1, col1  (Col1 + EUtrend + EUtrendsq)

ppmlhdfe trade emu emu_ONE cuwoemu  EU2 regional_woEU EUtrend EUtrendsq if year<2017, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
 

estimates store t1c1

* Table 1, col 2 (Col2 +EUtrend + EUtrendsq) 

ppmlhdfe trade emu emu_ONE cuwoemu  EU2 regional_woEU EUtrend EUtrendsq  if year<2017 & year2==1, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
	  

estimates store t1c2

* Table 1, col 3 (Col3 + EUtrend + EUtrendsq) 

ppmlhdfe trade emu emu_ONE cuwoemu  EU2 regional_woEU EUtrend EUtrendsq if year<2017 & year3==1, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
estimates store t1c3

* Table 1, col 4 (Col4 + EUtrend + EUtrendsq)

ppmlhdfe trade emu emu_ONE cuwoemu  EU2 regional_woEU EUtrend EUtrendsq  if year<2017 & year5==1, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
estimates store t1c12




* Table 1, col 5 (Col4 + EUtrend + EUtrendsq)
ppmlhdfe trade emu1999_07 emu2008_16 emu_ONE1999_07 emu_ONE2008_16 cuwoemu EU2 regional_woEU EUtrend EUtrendsq if year<2017, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)

estimates store t1c4

esttab t1c1 t1c2 t1c3 t1c4  ///
using "Table_1.csv", append ///
title(Table 1b. EMU effect on trade -PPML using intra-national trade)  ///
mtitles(col1 2-yr 3-yr 5-yr c5 2-yr 3_yr 5-yr) ///
b(3) se(3) scalars(N r2) star(* 0.10 ** .05 *** .01)  staraux nogaps 


*********************
*Table 2
*********************


local EU_cou "AUT BEL CYP DEU FRA ITA NLD IRL ESP PRT FIN GRC  MLT DNK GBR SWE HUN POL ROM BGR "
 
foreach name of local EU_cou {

ge `name'_X=(exporter=="`name'")

ge `name'_M=(importer=="`name'")

ge `name'= `name'_X + `name'_M

recode `name' 2=0
}



local euro_cou "AUT BEL FIN FRA DEU GRC IRL ITA NLD PRT ESP MLT CYP"

foreach name of local euro_cou {

ge euro`name'=emu*`name'
ge euro`name'_X=emu*`name'_X
ge euro`name'_M=emu*`name'_M

ge eurowo`name'=emu-euro`name'

}


local euro_cou "AUT BEL FIN FRA DEU GRC IRL ITA NLD PRT ESP MLT CYP"

foreach name of local euro_cou {

ge euro_one`name'=emu_ONE*`name'
ge euro_one`name'_X=emu_ONE*`name'_X
ge euro_one`name'_M=emu_ONE*`name'_M

ge euro_onewo`name'=emu_ONE-euro_one`name'

}



**
*** Table 2.- BY COUNTRY with EUtrend and EUtrendsq
**
*


local euro_cou "AUT BEL FIN FRA DEU GRC IRL ITA NLD PRT ESP MLT CYP"

foreach name of local euro_cou {

ppmlhdfe trade cuwoemu EU2 regional_woEU euro`name' eurowo`name' euro_one`name' euro_onewo`name' EUtrend EUtrendsq if year<2017, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
estimates store t2c1_`name' 

lincom euro`name'-eurowo`name'
test euro`name'=eurowo`name'

}

** at 2-yr interval 
foreach name of local euro_cou {

ppmlhdfe trade cuwoemu EU2 regional_woEU euro`name' eurowo`name' euro_one`name' euro_onewo`name' EUtrend EUtrendsq if year<2017 & year2==1, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
estimates store t2c2_`name' 

lincom euro`name'-eurowo`name'
test euro`name'=eurowo`name'

}

** at 3-yr interval 
foreach name of local euro_cou {

ppmlhdfe trade cuwoemu EU2 regional_woEU euro`name' eurowo`name' euro_one`name' euro_onewo`name' EUtrend EUtrendsq if year<2017 & year3==1, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
estimates store t2c3_`name' 

lincom euro`name'-eurowo`name'
test euro`name'=eurowo`name'

}

** at 5-yr interval 
foreach name of local euro_cou {

ppmlhdfe trade cuwoemu EU2 regional_woEU euro`name' eurowo`name' euro_one`name' euro_onewo`name' EUtrend EUtrendsq if year<2017 & year5==1, absorb(exp_year imp_year pairid_asym) cluster(pairid_asym)
estimates store t2c4_`name' 

lincom euro`name'-eurowo`name'
test euro`name'=eurowo`name'

}



*
* PRINT TABLE 2, col 1
* 
esttab t2c1_AUT t2c1_BEL t2c1_FIN t2c1_FRA t2c1_DEU t2c1_GRC t2c1_IRL t2c1_ITA t2c1_NLD t2c1_PRT t2c1_ESP t2c1_MLT t2c1_CYP ///
using "Table 2_col1.csv", replace ///
title(Table 2a. EMU effect by country: main results) mtitles(Z_intra_both_one) ///
b(3) se(3) scalars(N r2) star(* 0.10 ** .05 *** .01) drop(cuwoemu EU2 regional_woEU  eurowo* euro_onewo* EUtrend) staraux nogaps 


*
* PRINT TABLE 2, col 2 -- at 2-yr intervals 
* 
esttab t2c2_AUT t2c2_BEL t2c2_FIN t2c2_FRA t2c2_DEU t2c2_GRC t2c2_IRL t2c2_ITA t2c2_NLD t2c2_PRT t2c2_ESP t2c2_MLT t2c2_CYP ///
using "Table 2_col2.csv", replace ///
title(Table 2a. EMU effect by country: main results) mtitles(Z_intra_both_one) ///
b(3) se(3) scalars(N r2) star(* 0.10 ** .05 *** .01) drop(cuwoemu EU2 regional_woEU  eurowo* euro_onewo* EUtrend) staraux nogaps 


*
* PRINT TABLE 2, col 3 -- at 3-yr intervals 
* 
esttab t2c3_AUT t2c3_BEL t2c3_FIN t2c3_FRA t2c3_DEU t2c3_GRC t2c3_IRL t2c3_ITA t2c3_NLD t2c3_PRT t2c3_ESP t2c3_MLT t2c3_CYP ///
using "Table 2_col3.csv", replace ///
title(Table 2a. EMU effect by country: main results) mtitles(Z_intra_both_one) ///
b(3) se(3) scalars(N r2) star(* 0.10 ** .05 *** .01) drop(cuwoemu EU2 regional_woEU  eurowo* euro_onewo* EUtrend) staraux nogaps 


*
* PRINT TABLE 2, col 4 -- at 5-yr intervals 
* 
esttab t2c4_AUT t2c4_BEL t2c4_FIN t2c4_FRA t2c4_DEU t2c4_GRC t2c4_IRL t2c4_ITA t2c4_NLD t2c4_PRT t2c4_ESP t2c4_MLT t2c4_CYP ///
using "Table 2_col4.csv", replace ///
title(Table 2a. EMU effect by country: main results) mtitles(Z_intra_both_one) ///
b(3) se(3) scalars(N r2) star(* 0.10 ** .05 *** .01) drop(cuwoemu EU2 regional_woEU  eurowo* euro_onewo* EUtrend) staraux nogaps 



*******************
*Figure 1
*********************
sort pairid_asym year 
by pairid_asym: ge emu_tot=emu[_N]
label var emu_tot "=1 if the pair are EMU members by the end of sample period"
* beware that emu_tot takes value 0 for intra-national trade (i.e., importer = exporter)  

sort year importer emu trade 
qui by year importer: egen tot=total(trade) 
 
qui by year importer: egen tm_emu1=total(trade) if emu_tot==1 & importer!=exporter 
qui by year importer: egen tm_NO_emu1=total(trade) if emu_tot==0 & importer!=exporter
qui by year importer: egen t_intra1=total(trade) if importer==exporter 

qui by year importer: egen tm_emu=max(tm_emu1)

qui by year importer: egen tm_NO_emu=max(tm_NO_emu1)

qui by year importer: egen t_intra=max(t_intra1)


drop tm_emu1 tm_NO_emu1 t_intra1 


qui by year importer: ge id=_n

keep if id==1

ge sh_imp_emu=tm_emu/tot
ge sh_imp_no_emu=tm_NO_emu/tot 
ge sh_intra=t_intra/tot 


keep if tm_emu!=.



collapse (sum) tm_emu tm_NO_emu t_intra tot, by(year)

ge sh_imp_emu=tm_emu/tot
ge sh_imp_no_emu=tm_NO_emu/tot 
ge sh_intra=t_intra/tot 

twoway line sh_imp_emu sh_imp_no_emu sh_intra year, lpattern(dash dash_dot solid) ///
legend(lab(1 "Trade with EMU") lab(2 "Trade with non-EMU") lab(3 "Domestic trade") position(6)  rows(1) ) ///
scheme(cleanplots)

graph export "share.pdf", as(pdf) replace
graph export "share.png", replace



******************************************
*Counterfactual 1. Table 3 and Figure 2
******************************************

use "emu_ge_data_rev.dta", replace



egen exporter_id=group(exporter)
egen importer_id =group(importer)
egen pair_id =group(importer exporter)


******************
**GLOBALIZATION***
******************

gen INTL_BRDR=1 if exporter!=importer
replace INTL_BRDR=0 if INTL_BRDR==.
forvalues i=1986(1)2017{
gen INTL_BRDR_`i'=1 if INTL_BRDR==1 & year==`i'
replace INTL_BRDR_`i'=0 if INTL_BRDR_`i'==.
}


egen trend=group(year)
ge EUtrend=EU2*trend
ge EUtrend2=EU2*trend*trend

ge custrict11_wo_emu= custrict11- CUEURO2

foreach var in CUEURO2 CUEURO1 EU2 custrict11_wo_emu rta_woEU2 EUtrend EUtrend2  {
replace `var'=0 if exporter==importer
}


ge LN_DIST =log(DIST) 
rename INTL_BRDR BRDR


****************
**EU variables***
****************

ge eu_i=0
ge eu_j=0



replace eu_i=1 if exporter=="AUT"
replace eu_i=1 if exporter=="BEL"
replace eu_i=1 if exporter=="BGR" & year>=2007
replace eu_i=1 if exporter=="HRV" & year>=2013
replace eu_i=1 if exporter=="CYP" & year>=2004
replace eu_i=1 if exporter=="CZE" & year>=2004
replace eu_i=1 if exporter=="DNK"
replace eu_i=1 if exporter=="EST" & year>=2004
replace eu_i=1 if exporter=="FIN" 
replace eu_i=1 if exporter=="FRA"
replace eu_i=1 if exporter=="DEU"
replace eu_i=1 if exporter=="GRC"

replace eu_i=1 if exporter=="IRL"
replace eu_i=1 if exporter=="HUN" & year>=2004
replace eu_i=1 if exporter=="ITA" 
replace eu_i=1 if exporter=="LVA" & year>=2004
replace eu_i=1 if exporter=="LTU" & year>=2004
replace eu_i=1 if exporter=="LUX"
replace eu_i=1 if exporter=="MLT" & year>=2004
replace eu_i=1 if exporter=="POL" & year>=2004
replace eu_i=1 if exporter=="NLD" 
replace eu_i=1 if exporter=="PRT"
replace eu_i=1 if exporter=="ROM" & year>=2007
replace eu_i=1 if exporter=="SVK" & year>=2004
replace eu_i=1 if exporter=="SVN" & year>=2004
replace eu_i=1 if exporter=="ESP"
replace eu_i=1 if exporter=="SWE" 
replace eu_i=1 if exporter=="GBR"
replace eu_i=1 if exporter=="ESP"

replace eu_j=1 if importer=="AUT"
replace eu_j=1 if importer=="BEL"
replace eu_j=1 if importer=="BGR" & year>=2007
replace eu_j=1 if importer=="HRV" & year>=2013
replace eu_j=1 if importer=="CYP" & year>=2004
replace eu_j=1 if importer=="CZE" & year>=2004
replace eu_j=1 if importer=="DNK"
replace eu_j=1 if importer=="EST" & year>=2004
replace eu_j=1 if importer=="FIN" 
replace eu_j=1 if importer=="FRA"
replace eu_j=1 if importer=="DEU"
replace eu_j=1 if importer=="GRC"

replace eu_j=1 if importer=="IRL"
replace eu_j=1 if importer=="HUN" & year>=2004
replace eu_j=1 if importer=="ITA" 
replace eu_j=1 if importer=="LVA" & year>=2004
replace eu_j=1 if importer=="LTU" & year>=2004
replace eu_j=1 if importer=="LUX"
replace eu_j=1 if importer=="MLT" & year>=2004
replace eu_j=1 if importer=="POL" & year>=2004
replace eu_j=1 if importer=="NLD" 
replace eu_j=1 if importer=="PRT"
replace eu_j=1 if importer=="ROM" & year>=2007
replace eu_j=1 if importer=="SVK" & year>=2004
replace eu_j=1 if importer=="SVN" & year>=2004
replace eu_j=1 if importer=="ESP"
replace eu_j=1 if importer=="SWE" 
replace eu_j=1 if importer=="GBR"
replace eu_j=1 if importer=="ESP"


ge EU=eu_j*eu_i*BRDR




**************
*EURO*********
**************




ge euro_i=0
ge euro_j=0

replace euro_i=1 if exporter=="DEU" & year>=1999
replace euro_i=1 if exporter=="AUT" & year>=1999
replace euro_i=1 if exporter=="BEL" & year>=1999
replace euro_i=1 if exporter=="FIN" & year>=1999
replace euro_i=1 if exporter=="FRA" & year>=1999
replace euro_i=1 if exporter=="IRL" & year>=1999
replace euro_i=1 if exporter=="ITA" & year>=1999
replace euro_i=1 if exporter=="LUX" & year>=1999
replace euro_i=1 if exporter=="NLD" & year>=1999
replace euro_i=1 if exporter=="PRT" & year>=1999
replace euro_i=1 if exporter=="ESP" & year>=1999
replace euro_i=1 if exporter=="GRC" & year>=2001

replace euro_j=1 if importer=="DEU" & year>=1999
replace euro_j=1 if importer=="AUT" & year>=1999
replace euro_j=1 if importer=="BEL" & year>=1999
replace euro_j=1 if importer=="FIN" & year>=1999
replace euro_j=1 if importer=="FRA" & year>=1999
replace euro_j=1 if importer=="IRL" & year>=1999
replace euro_j=1 if importer=="ITA" & year>=1999
replace euro_j=1 if importer=="LUX" & year>=1999
replace euro_j=1 if importer=="NLD" & year>=1999
replace euro_j=1 if importer=="PRT" & year>=1999
replace euro_j=1 if importer=="ESP" & year>=1999
replace euro_j=1 if importer=="GRC" & year>=2001

replace euro_j=1 if importer=="SVN" & year>=2007
replace euro_j=1 if importer=="CYP" & year>=2008
replace euro_j=1 if importer=="MLT" & year>=2008

replace euro_j=1 if importer=="SVK" & year>=2009
replace euro_j=1 if importer=="EST" & year>=2011
replace euro_j=1 if importer=="LVA" & year>=2014
replace euro_j=1 if importer=="LTU" & year>=2015

replace euro_i=1 if exporter=="SVN" & year>=2007
replace euro_i=1 if exporter=="CYP" & year>=2008
replace euro_i=1 if exporter=="MLT" & year>=2008

replace euro_i=1 if exporter=="SVK" & year>=2009
replace euro_i=1 if exporter=="EST" & year>=2011
replace euro_i=1 if exporter=="LVA" & year>=2014
replace euro_i=1 if exporter=="LTU" & year>=2015

ge EURO=euro_i*BRDR



eststo: ppmlhdfe trade  CUEURO2 CUEURO1 EU2 custrict11_wo_emu rta_woEU2 EUtrend EUtrend2  ///
, absorb(pair_id exporter_id#year importer_id#year ) cluster(pair_id )




ge b_emu2=_b[CUEURO2]
ge b_emu1=_b[CUEURO1]












keep if year==2016


*Countries causing trouble

drop if exporter=="ARG"
drop if importer=="ARG"


drop if exporter=="MAC"
drop if importer=="MAC"


*******************************
*2. Create aggregate variables*
*******************************
*Market clearce condition: since we have internal trade this is total output

bysort exporter: egen output=sum(trade)
bysort importer: egen expndr=sum(trade)

****************************************
*3. Chose a country for reference group*
****************************************
replace exporter="ZZZ" if exporter=="USA"
replace importer="ZZZ" if importer=="USA"

*FE will be interptreated as expenditure.
gen expndr_deu0=expndr if importer=="ZZZ"

*Rescale all FE creating a variaBEL all values are DEU expenditure
egen expndr_deu=mean(expndr_deu0)
*************************
*4. Create Fixed Effects*
*************************
*MR from these FE

qui tab exporter, gen(exp_fe_)
qui tab importer, gen(imp_fe_)

qui tab exporter
local NoC=r(r)
sort imp_fe_`NoC'
*This is DEU by construction (that will be dropped)

******************************
*5. Set additional parameters*
****************************** 

*NoC: number of countries

gen double phi=expndr/output if exporter==importer
scalar sigma=7
qui tab exporter
local NoC=r(r)
save ge_ppml_data, replace

ppml trade LN_DIST CNTG BRDR  CUEURO2 CUEURO1  custrict11_wo_emu rta_woEU2   exp_fe_* imp_fe_1-imp_fe_`=`NoC'-1', iter(30) noconst 

predict trade_0_pred, mu






******************************************
*Step 1.a: Conscrut `Baseline' GE Indexes*
******************************************
forvalues i=1(1)`=`NoC'-1'{
qui replace exp_fe_`i'=exp_fe_`i'*exp(_b[exp_fe_`i']) 
qui replace imp_fe_`i'=imp_fe_`i'*exp(_b[imp_fe_`i'])
}
**** 2 variables with FE estimates and recover MR from these variables 
*Step 1b on the importer side, on the exporter side from 1 to 68
*Doping the same thing ouside the loop for the last FE (DEU
qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])


*Summing for
egen all_exp_fes_0=rowtotal(exp_fe_1-exp_fe_`NoC')
egen all_imp_fes_0=rowtotal(imp_fe_1-imp_fe_`NoC') 


gen t_ij_BLN=exp(_b[LN_DIST]*LN_DIST+_b[CNTG]*CNTG+_b[BRDR]*BRDR + b_emu2*CUEURO2 + b_emu1*CUEURO1 + _b[custrict11_wo_emu]*custrict11_wo_emu + _b[rta_woEU2]*rta_woEU2 )

*baseline 
gen output_BLN=output
gen expndr_BLN=expndr

*Constructing the MR terms ppml solved the non-linear system for us.
gen omr_BLN=output_BLN*expndr_deu/(all_exp_fes_0)
gen imr_BLN=expndr_BLN/(all_imp_fes_0*expndr_deu)

*data or data // predition vs prediction we need to be consistent
gen trade_BLN=(output_BLN*expndr_BLN*t_ij_BLN)/(imr_BLN*omr_BLN)


*Compate real GDP and total exports as the sum of exports 

gen double exp_BLN=trade_BLN if exporter!=importer
bysort exporter: egen tot_exp_BLN=sum(exp_BLN)



****************************************
*Step 2: Define Counterfactual Scenario*
****************************************
*replace EURO=0

gen t_ij_CFL=exp(_b[LN_DIST]*LN_DIST+_b[CNTG]*CNTG+_b[BRDR]*BRDR + _b[custrict11_wo_emu]*custrict11_wo_emu + _b[rta_woEU2]*rta_woEU2 )


gen t_ij_CFL_1=log(t_ij_CFL)


****************************************
*Step 3: Estimate `Conditional' Gravity*
****************************************
*Solve the model in counterfactual here size does not change.

*Dropping beacause replace them with their estimates
drop exp_fe_* imp_fe_*
qui tab exporter, gen(exp_fe_)
qui tab importer, gen(imp_fe_)

*offset imposes a constraint 
*ppml given new trade cost vector solve the MR

ppml trade exp_fe_* imp_fe_1-imp_fe_`=`NoC'-1', iter(30) noconst offset(t_ij_CFL_1) keep
predict trade_1_pred, mu
**********************************************
*Step 3.b: Construct `Conditional' GE Indexes*
**********************************************
forvalues i=1(1)`=`NoC'-1'{
qui replace exp_fe_`i'=exp_fe_`i'*exp(_b[exp_fe_`i'])
qui replace imp_fe_`i'=imp_fe_`i'*exp(_b[imp_fe_`i'])
}
qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])
egen all_exp_fes_1=rowtotal(exp_fe_1-exp_fe_`NoC')
egen all_imp_fes_1=rowtotal(imp_fe_1-imp_fe_`NoC') 
gen omr_CDL=output*expndr_deu/(all_exp_fes_1)
gen imr_CDL=expndr/(all_imp_fes_1*expndr_deu)
gen output_CDL=output
gen expndr_CDL=expndr
gen trade_CDL=(output_CDL*expndr_CDL*t_ij_CFL)/(imr_CDL*omr_CDL)
gen double exp_CDL=trade_CDL if exporter!=importer
bysort exporter: egen tot_exp_CDL=sum(exp_CDL)


*up to here we have solve in the conditional scenario

*lklkmlkm
*******************************************
*Step 4: Estimate `Full Endowment' Gravity*
*******************************************
*************************************
*Step 4.a: Prepare Initial Variables*
*************************************
*allow for endogenous size, allo from market clearing conditions
*instead of chaning the FE, use theory and update the trade flows
*estimate with the new value of trade
*construct new factory gate prices and 


gen expndr_1=expndr
gen double expndr_deu_1=expndr_deu
gen double temp1=all_exp_fes_0 if exporter==importer
bysort importer: egen double all_exp_fes_0_imp=mean(temp1)
gen double temp2=all_exp_fes_1 if exporter==importer
bysort importer: egen double all_exp_fes_1_imp=mean(temp2)

*FActory gate prices and changes
gen double p_FLL_exp_1=(all_exp_fes_1/all_exp_fes_0)^(1/(1-sigma))
gen double p_FLL_imp_1=(all_exp_fes_1_imp/all_exp_fes_0_imp)^(1/(1-sigma))
gen double p_FLL_exp_0=0
gen double imr_FLL_1=expndr_1/(all_imp_fes_1*expndr_deu_1)
gen double imr_FLL_ch_1=1
gen double omr_FLL_1=output*expndr_deu_1/(all_exp_fes_1)
gen double omr_FLL_ch_1=1
drop *temp*
******************************************************
*Step 4.b: Iterate to obtain `Full Endowment' indexes*
******************************************************
local i=3
local diff_all_exp_fes_sd=1
local diff_all_exp_fes_max=1
*I want to stop when the diferences in gate prices is zero
while (`diff_all_exp_fes_sd'>0.1) | (`diff_all_exp_fes_max'>0.1) {
		*******************************************************
		*i. Create new dependent variable and estimate gravity*
		*******************************************************
		*Gebnerating trade from theory from chaning prices
		gen double trade_`=`i'-1'=trade_`=`i'-2'_pred*p_FLL_exp_`=`i'-2'*p_FLL_imp_`=`i'-2'/(omr_FLL_ch_`=`i'-2'*imr_FLL_ch_`=`i'-2')
		drop exp_fe_* imp_fe_*
		qui tab exporter, gen (exp_fe_)
		qui tab importer, gen (imp_fe_)
		capture ppml trade_`=`i'-1' exp_fe_* imp_fe_*, offset(t_ij_CFL_1) noconst iter(30) 
		predict trade_`=`i'-1'_pred, mu
		*********************************
		*ii. Update output & expenditure*
		*********************************
		bysort exporter: egen double output_`=`i'-1'=total(trade_`=`i'-1'_pred)
		gen double expndr_temp_`=`i'-1'=phi*output_`=`i'-1' if exporter==importer
		bysort importer: egen double expndr_`=`i'-1'=mean(expndr_temp_`=`i'-1')
		gen double expndr_deu0_`=`i'-1'=expndr_`=`i'-1' if importer=="ZZZ"
		egen double expndr_deu_`=`i'-1'=mean(expndr_deu0_`=`i'-1')
		***********************************************
		*iii. Update factory-gate prices & resistances*
		***********************************************
		*Update MR like before
		
		forvalues j=1(1)`=`NoC'-1'{
		qui replace exp_fe_`j'=exp_fe_`j'*exp(_b[exp_fe_`j'])
		qui replace imp_fe_`j'=imp_fe_`j'*exp(_b[imp_fe_`j'])
		}
		qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])
		egen all_exp_fes_`=`i'-1'=rowtotal(exp_fe_1-exp_fe_`NoC')
		egen all_imp_fes_`=`i'-1'=rowtotal(imp_fe_1-imp_fe_`NoC') 
		gen double temp=all_exp_fes_`=`i'-1' if exporter==importer
		bysort importer: egen double all_exp_fes_`=`i'-1'_imp=mean(temp)
		gen double p_FLL_exp_`=`i'-1'=((all_exp_fes_`=`i'-1'/all_exp_fes_`=`i'-2')/(expndr_deu_`=`i'-1'/expndr_deu_`=`i'-2'))^(1/(1-sigma))
		gen double p_FLL_imp_`=`i'-1'=((all_exp_fes_`=`i'-1'_imp/all_exp_fes_`=`i'-2'_imp)/(expndr_deu_`=`i'-1'/expndr_deu_`=`i'-2'))^(1/(1-sigma))
		gen double omr_FLL_`=`i'-1'=(output_`=`i'-1'*expndr_deu_`=`i'-1')/all_exp_fes_`=`i'-1'
		gen double omr_FLL_ch_`=`i'-1'=omr_FLL_`=`i'-1'/omr_FLL_`=`i'-2'
		gen double imr_FLL_`=`i'-1'=expndr_`=`i'-1'/(all_imp_fes_`=`i'-1'*expndr_deu_`=`i'-1')
		gen double imr_FLL_ch_`=`i'-1'=imr_FLL_`=`i'-1'/imr_FLL_`=`i'-2'
		****************************************************************************
		*iv. Iterate Until Convergence: Until change in factory-gate prices is zero*
		****************************************************************************
		gen double diff_p_FLL_exp_`=`i'-1'=p_FLL_exp_`=`i'-2'-p_FLL_exp_`=`i'-3'
		sum diff_p_FLL_exp_`=`i'-1'
		local diff_all_exp_fes_sd=r(sd)
		local diff_all_exp_fes_max=abs(r(max))
		local i=`i'+1
		drop temp* 
}
*************************************************
*Step 4.c: Construct `Full Endowment' GE Indexes*
*************************************************


*Cllection importer FE
forvalues j=1(1)`=`NoC'-1'{
qui replace imp_fe_`j'=imp_fe_`j'*exp(_b[imp_fe_`j'])
}

*Full factory price change
gen double p_FLL=((all_exp_fes_`=`i'-2'/all_exp_fes_0)/(expndr_deu_`=`i'-2'/expndr_deu))^(1/(1-sigma))
gen output_FLL=p_FLL*output
gen double expndr_FLL_temp=phi*output_FLL if exporter==importer
bysort importer: egen double expndr_FLL=mean(expndr_FLL_temp)

*Outward, importer resistance
gen double omr_FLL=output_FLL*expndr_deu_`=`i'-2'/(all_exp_fes_`=`i'-2')
gen double imr_FLL=expndr_`=`i'-2'/(all_imp_fes_`=`i'-2'*expndr_deu_`=`i'-2')
gen trade_FLL=(output_FLL*expndr_FLL*t_ij_CFL)/(imr_FLL*omr_FLL)
gen double exp_FLL=trade_FLL if exporter!=importer
bysort exporter: egen tot_exp_FLL=sum(exp_FLL)
save full_static_all, replace

**************************************
*Step 5: Construct Percentage Changes*
**************************************
******************************
*a. On Export/Production Side*
******************************
*FActory gate prices where assumed to be 1

use full_static_all, clear
collapse omr_FLL omr_CDL omr_BLN p_FLL output* expndr* tot_exp* (firstnm) eu_j euro_j , by(exporter)
gen p_FLL_ch=(p_FLL-1)*100

*The model solves for the resistances of 1-sigma
gen omr_FLL_ch=(omr_FLL^(1/(1-sigma))-omr_BLN^(1/(1-sigma)))/omr_BLN^(1/(1-sigma))*100
gen omr_CDL_ch=(omr_CDL^(1/(1-sigma))-omr_BLN^(1/(1-sigma)))/omr_BLN^(1/(1-sigma))*100
gen tot_exp_FLL_ch=(tot_exp_FLL-tot_exp_BLN)/tot_exp_BLN*100
gen tot_exp_CDL_ch=(tot_exp_CDL-tot_exp_BLN)/tot_exp_BLN*100
rename exporter country
save prod_all, replace
*******************************
*b. On Import/Consumption Side*
*******************************
use full_static_all, clear
collapse imr_FLL imr_BLN imr_CDL (firstnm) eu_j euro_j , by(importer)
rename importer country
gen imr_FLL_ch=(imr_FLL^(1/(1-sigma))-imr_BLN^(1/(1-sigma)))/imr_BLN^(1/(1-sigma))*100
gen imr_CDL_ch=(imr_CDL^(1/(1-sigma))-imr_BLN^(1/(1-sigma)))/imr_BLN^(1/(1-sigma))*100
save cons_all, replace
*************************************
*c. Combine and Export to Tex/Excell*
*************************************

joinby country using prod_all
gen rGDP_BLN=output_BLN/(imr_BLN^(1/(1-sigma)))
gen rGDP_FLL=output_FLL/(imr_FLL^(1/(1-sigma)))
gen rGDP_FLL_ch=(rGDP_FLL-rGDP_BLN)/rGDP_BLN*100
keep country tot_exp_CDL_ch tot_exp_FLL_ch p_FLL_ch imr_FLL_ch omr_FLL_ch rGDP_FLL_ch eu_j euro_j 
order country tot_exp_CDL_ch tot_exp_FLL_ch p_FLL_ch imr_FLL_ch rGDP_FLL_ch

sort rGDP_FLL_ch

ge GDPchange=1+rGDP_FLL_ch/100

ge ConsPrch=1+imr_FLL_ch/100

ge ProPrch=1+p_FLL_ch/100

ge Exportch=1+tot_exp_FLL_ch/100

ameans GDPchange ProPrch ConsPrch Exportch
ge GDPAve=r(mean_g)


****For display and calculation pursopese****


*****

generate pos = runiform(1,12)
recast int pos, force

ge n=_n



ameans GDPchange
local GDPctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if eu_j==1 & euro_j==0
local GDPcoecd : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if euro_j==1 
local GDPlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if eu_j==0 & euro_j==0
local GDPcrow : display %04.2f round((r(mean_g)-1)*100,0.0005)


ameans  ProPrch 
local ProPrchctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if eu_j==1 & euro_j==0
local ProPrchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if euro_j==1 
local ProPrchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if eu_j==0 & euro_j==0
local ProPrchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)


ameans ConsPrch
local ConsPrchctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if eu_j==1 & euro_j==0
local ConsPrchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if euro_j==1 
local ConsPrchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if eu_j==0 & euro_j==0
local ConsPrchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)


ameans Exportch
local Exportchtot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if eu_j==1 & euro_j==0
local Exportchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if euro_j==1 
local Exportchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if eu_j==0 & euro_j==0
local Exportchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)


dataout, save(EURO_table_3) word tex replace dec(2)

drop if rGDP_FLL_ch>10
*drop if country=="CMR"



*twoway scatter p_FLL_ch cpiXBRDR_j, mlab( country) mlabs(tiny) mlabv(pos) || lfit p_FLL_ch cpiXBRDR_j, 


#delimit ;
twoway scatter tot_exp_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter tot_exp_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter tot_exp_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Exports change") 
subtitle("(a) Exports Change ")
note("World Exports Change `Exportchtot'%" "ROW Exports Change `Exportchrow'%" "EU-non-EMU Exports Change `Exportchcoecd'%" "EMU Exports Change `Exportchlow'%"  )
legend(off) scheme(cleanplots)
;

#delimit cr

#delimit cr

graph save CF1_LOW_GDP1.gph, replace
*graph export "$main\CF1_LOW_GDP1.pdf", as(pdf) replace

#delimit ;
twoway scatter rGDP_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter rGDP_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter rGDP_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("GDP change") 
subtitle("(b) GDP Change ")
note("World GDP Change `GDPctot'%" "ROW GDP Change `GDPcrow'%" "EU-non-EMU GDP Change `GDPcoecd'%" "EMU GDP Change `GDPlow'%"  )
legend(off) scheme(cleanplots)
;

#delimit cr

graph save CF1_LOW_GDP.gph, replace
*graph export "$main\CF1_LOW_GDP.pdf", as(pdf) replace

#delimit ;
twoway scatter imr_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter imr_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter imr_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Consumer prices change") 
subtitle("(c) Consumer prices ")
note("World Consumer prices Change `ConsPrchctot'%" "ROW Consumer prices Change `ConsPrchrow'%" "EU-non-EMU Consumer prices Change `ConsPrchcoecd'%" "EMU Consumer prices Change `ConsPrchlow'%" )
legend(off) scheme(cleanplots)
;
#delimit cr
graph save CF1_LOW_CP.gph, replace
*graph export "$main\CF1_LOW_CP.pdf", as(pdf) replace

#delimit ;
twoway scatter p_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter p_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter p_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Producer prices change /USA") 
subtitle("(d) Producer prices ")
note("World Producer prices Change `ProPrchctot'%" "ROW Producer prices Change `ProPrchrow'%" "EU-non-EMU Producer prices Change `ProPrchcoecd'%" "EMU Producer prices Change `ProPrchlow'%" )
legend(off) scheme(cleanplots)
;
#delimit cr

graph save CF1_LOW_PP.gph, replace

*graph export "$main\CF1_LOW_PP.pdf", as(pdf) replace

graph combine  CF1_LOW_GDP1.gph CF1_LOW_GDP.gph  CF1_LOW_CP.gph CF1_LOW_PP.gph, title("Counterfactual CF1: NO EURO")  scheme(cleanplots)

graph export "Figure 2 Counterfactual 1 EURO.pdf", as(pdf) replace
graph export "Figure 2 Counterfactual 1 EURO.png", replace


local datafiles: dir . files "CF*"
foreach datafile of local datafiles {
        erase "`datafile'"
}


******************************************
*Counterfactual 2. Table 4 and Figure 3
******************************************


use "emu_ge_data_rev.dta", replace
*****************************************************
**International border 
** Intl trade relative to domestic o regional trade**
*****************************************************



egen exporter_id=group(exporter)
egen importer_id =group(importer)
egen pair_id =group(importer exporter)




******************
**GLOBALIZATION***
******************

gen INTL_BRDR=1 if exporter!=importer
replace INTL_BRDR=0 if INTL_BRDR==.
forvalues i=1986(1)2017{
gen INTL_BRDR_`i'=1 if INTL_BRDR==1 & year==`i'
replace INTL_BRDR_`i'=0 if INTL_BRDR_`i'==.
}


egen trend=group(year)
ge EUtrend=EU2*trend
ge EUtrend2=EU2*trend*trend

ge custrict11_wo_emu= custrict11- CUEURO2

foreach var in CUEURO2 CUEURO1 EU2 custrict11_wo_emu rta_woEU2 EUtrend EUtrend2  {
replace `var'=0 if exporter==importer
}


ge LN_DIST =log(DIST) 
rename INTL_BRDR BRDR


****************
**EU variables***
****************

ge eu_i=0
ge eu_j=0



replace eu_i=1 if exporter=="AUT"
replace eu_i=1 if exporter=="BEL"
replace eu_i=1 if exporter=="BGR" & year>=2007
replace eu_i=1 if exporter=="HRV" & year>=2013
replace eu_i=1 if exporter=="CYP" & year>=2004
replace eu_i=1 if exporter=="CZE" & year>=2004
replace eu_i=1 if exporter=="DNK"
replace eu_i=1 if exporter=="EST" & year>=2004
replace eu_i=1 if exporter=="FIN" 
replace eu_i=1 if exporter=="FRA"
replace eu_i=1 if exporter=="DEU"
replace eu_i=1 if exporter=="GRC"

replace eu_i=1 if exporter=="IRL"
replace eu_i=1 if exporter=="HUN" & year>=2004
replace eu_i=1 if exporter=="ITA" 
replace eu_i=1 if exporter=="LVA" & year>=2004
replace eu_i=1 if exporter=="LTU" & year>=2004
replace eu_i=1 if exporter=="LUX"
replace eu_i=1 if exporter=="MLT" & year>=2004
replace eu_i=1 if exporter=="POL" & year>=2004
replace eu_i=1 if exporter=="NLD" 
replace eu_i=1 if exporter=="PRT"
replace eu_i=1 if exporter=="ROM" & year>=2007
replace eu_i=1 if exporter=="SVK" & year>=2004
replace eu_i=1 if exporter=="SVN" & year>=2004
replace eu_i=1 if exporter=="ESP"
replace eu_i=1 if exporter=="SWE" 
replace eu_i=1 if exporter=="GBR"
replace eu_i=1 if exporter=="ESP"

replace eu_j=1 if importer=="AUT"
replace eu_j=1 if importer=="BEL"
replace eu_j=1 if importer=="BGR" & year>=2007
replace eu_j=1 if importer=="HRV" & year>=2013
replace eu_j=1 if importer=="CYP" & year>=2004
replace eu_j=1 if importer=="CZE" & year>=2004
replace eu_j=1 if importer=="DNK"
replace eu_j=1 if importer=="EST" & year>=2004
replace eu_j=1 if importer=="FIN" 
replace eu_j=1 if importer=="FRA"
replace eu_j=1 if importer=="DEU"
replace eu_j=1 if importer=="GRC"

replace eu_j=1 if importer=="IRL"
replace eu_j=1 if importer=="HUN" & year>=2004
replace eu_j=1 if importer=="ITA" 
replace eu_j=1 if importer=="LVA" & year>=2004
replace eu_j=1 if importer=="LTU" & year>=2004
replace eu_j=1 if importer=="LUX"
replace eu_j=1 if importer=="MLT" & year>=2004
replace eu_j=1 if importer=="POL" & year>=2004
replace eu_j=1 if importer=="NLD" 
replace eu_j=1 if importer=="PRT"
replace eu_j=1 if importer=="ROM" & year>=2007
replace eu_j=1 if importer=="SVK" & year>=2004
replace eu_j=1 if importer=="SVN" & year>=2004
replace eu_j=1 if importer=="ESP"
replace eu_j=1 if importer=="SWE" 
replace eu_j=1 if importer=="GBR"
replace eu_j=1 if importer=="ESP"


ge EU=eu_j*eu_i*BRDR




**************
*EURO*********
**************




ge euro_i=0
ge euro_j=0

replace euro_i=1 if exporter=="DEU" & year>=1999
replace euro_i=1 if exporter=="AUT" & year>=1999
replace euro_i=1 if exporter=="BEL" & year>=1999
replace euro_i=1 if exporter=="FIN" & year>=1999
replace euro_i=1 if exporter=="FRA" & year>=1999
replace euro_i=1 if exporter=="IRL" & year>=1999
replace euro_i=1 if exporter=="ITA" & year>=1999
replace euro_i=1 if exporter=="LUX" & year>=1999
replace euro_i=1 if exporter=="NLD" & year>=1999
replace euro_i=1 if exporter=="PRT" & year>=1999
replace euro_i=1 if exporter=="ESP" & year>=1999
replace euro_i=1 if exporter=="GRC" & year>=2001

replace euro_j=1 if importer=="DEU" & year>=1999
replace euro_j=1 if importer=="AUT" & year>=1999
replace euro_j=1 if importer=="BEL" & year>=1999
replace euro_j=1 if importer=="FIN" & year>=1999
replace euro_j=1 if importer=="FRA" & year>=1999
replace euro_j=1 if importer=="IRL" & year>=1999
replace euro_j=1 if importer=="ITA" & year>=1999
replace euro_j=1 if importer=="LUX" & year>=1999
replace euro_j=1 if importer=="NLD" & year>=1999
replace euro_j=1 if importer=="PRT" & year>=1999
replace euro_j=1 if importer=="ESP" & year>=1999
replace euro_j=1 if importer=="GRC" & year>=2001

replace euro_j=1 if importer=="SVN" & year>=2007
replace euro_j=1 if importer=="CYP" & year>=2008
replace euro_j=1 if importer=="MLT" & year>=2008

replace euro_j=1 if importer=="SVK" & year>=2009
replace euro_j=1 if importer=="EST" & year>=2011
replace euro_j=1 if importer=="LVA" & year>=2014
replace euro_j=1 if importer=="LTU" & year>=2015

replace euro_i=1 if exporter=="SVN" & year>=2007
replace euro_i=1 if exporter=="CYP" & year>=2008
replace euro_i=1 if exporter=="MLT" & year>=2008

replace euro_i=1 if exporter=="SVK" & year>=2009
replace euro_i=1 if exporter=="EST" & year>=2011
replace euro_i=1 if exporter=="LVA" & year>=2014
replace euro_i=1 if exporter=="LTU" & year>=2015

ge EURO=euro_i*BRDR




**************
*EURO CFLT****
**************




ge euro_core_i=0
ge euro_core_j=0

replace euro_core_i=1 if exporter=="DEU" & year>=1999
replace euro_core_i=1 if exporter=="AUT" & year>=1999
replace euro_core_i=1 if exporter=="BEL" & year>=1999
replace euro_core_i=1 if exporter=="FIN" & year>=1999
replace euro_core_i=1 if exporter=="FRA" & year>=1999
replace euro_core_i=1 if exporter=="LUX" & year>=1999
replace euro_core_i=1 if exporter=="NLD" & year>=1999



replace euro_core_j=1 if importer=="DEU" & year>=1999
replace euro_core_j=1 if importer=="AUT" & year>=1999
replace euro_core_j=1 if importer=="BEL" & year>=1999
replace euro_core_j=1 if importer=="FIN" & year>=1999
replace euro_core_j=1 if importer=="FRA" & year>=1999
replace euro_core_j=1 if importer=="LUX" & year>=1999
replace euro_core_j=1 if importer=="NLD" & year>=1999

ge euro_core=euro_core_i*BRDR

ge emu1_core=(euro_core_i+euro_core_j)*BRDR
replace emu1_core=0 if emu1_core==2


replace CUEURO2=CUEURO2-euro_core
replace CUEURO1=CUEURO1-emu1_core

eststo: ppmlhdfe trade  CUEURO2 CUEURO1 euro_core emu1_core EU2 custrict11_wo_emu rta_woEU2 EUtrend EUtrend2  ///
, absorb(pair_id exporter_id#year importer_id#year ) cluster(pair_id )




ge b_emu2=_b[CUEURO2]
ge b_emu1=_b[CUEURO1]

ge b_euro_core=_b[euro_core]
ge b_emu1_core=_b[emu1_core]




keep if year==2016




drop if exporter=="ARG"
drop if importer=="ARG"


drop if exporter=="MAC"
drop if importer=="MAC"


*******************************
*2. Create aggregate variables*
*******************************
*Market clearce condition: since we have internal trade this is total output

bysort exporter: egen output=sum(trade)
bysort importer: egen expndr=sum(trade)

****************************************
*3. Chose a country for reference group*
****************************************
replace exporter="ZZZ" if exporter=="USA"
replace importer="ZZZ" if importer=="USA"

*FE will be interptreated as expenditure.
gen expndr_deu0=expndr if importer=="ZZZ"

*Rescale all FE creating a variaBEL all values are DEU expenditure
egen expndr_deu=mean(expndr_deu0)
*************************
*4. Create Fixed Effects*
*************************
*MR from these FE

qui tab exporter, gen(exp_fe_)
qui tab importer, gen(imp_fe_)

qui tab exporter
local NoC=r(r)
sort imp_fe_`NoC'
*This is DEU by construction (that will be dropped)

******************************
*5. Set additional parameters*
****************************** 

*NoC: number of countries

gen double phi=expndr/output if exporter==importer
scalar sigma=7
qui tab exporter
local NoC=r(r)
save ge_ppml_data, replace

ppml trade LN_DIST CNTG BRDR  CUEURO2 CUEURO1 euro_core emu1_core custrict11_wo_emu rta_woEU2   exp_fe_* imp_fe_1-imp_fe_`=`NoC'-1', iter(30) noconst 

predict trade_0_pred, mu






******************************************
*Step 1.a: Conscrut `Baseline' GE Indexes*
******************************************
forvalues i=1(1)`=`NoC'-1'{
qui replace exp_fe_`i'=exp_fe_`i'*exp(_b[exp_fe_`i']) 
qui replace imp_fe_`i'=imp_fe_`i'*exp(_b[imp_fe_`i'])
}
**** 2 variables with FE estimates and recover MR from these variables 
*Step 1b on the importer side, on the exporter side from 1 to 68
*Doping the same thing ouside the loop for the last FE (DEU
qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])


*Summing for
egen all_exp_fes_0=rowtotal(exp_fe_1-exp_fe_`NoC')
egen all_imp_fes_0=rowtotal(imp_fe_1-imp_fe_`NoC') 


gen t_ij_BLN=exp(_b[LN_DIST]*LN_DIST+_b[CNTG]*CNTG+_b[BRDR]*BRDR + b_emu2*CUEURO2 + b_emu1*CUEURO1 +b_euro_core*euro_core + b_emu1_core*emu1_core+ _b[custrict11_wo_emu]*custrict11_wo_emu + _b[rta_woEU2]*rta_woEU2 )



*baseline 
gen output_BLN=output
gen expndr_BLN=expndr

*Constructing the MR terms ppml solved the non-linear system for us.
gen omr_BLN=output_BLN*expndr_deu/(all_exp_fes_0)
gen imr_BLN=expndr_BLN/(all_imp_fes_0*expndr_deu)

*data or data // predition vs prediction we need to be consistent
gen trade_BLN=(output_BLN*expndr_BLN*t_ij_BLN)/(imr_BLN*omr_BLN)


*Compate real GDP and total exports as the sum of exports 

gen double exp_BLN=trade_BLN if exporter!=importer
bysort exporter: egen tot_exp_BLN=sum(exp_BLN)



****************************************
*Step 2: Define Counterfactual Scenario*
****************************************


gen t_ij_CFL=exp(_b[LN_DIST]*LN_DIST+_b[CNTG]*CNTG+_b[BRDR]*BRDR +b_euro_core*euro_core + b_emu1_core*emu1_core+ _b[custrict11_wo_emu]*custrict11_wo_emu + _b[rta_woEU2]*rta_woEU2 )


gen t_ij_CFL_1=log(t_ij_CFL)


****************************************
*Step 3: Estimate `Conditional' Gravity*
****************************************
*Solve the model in counterfactual here size does not change.

*Dropping beacause replace them with their estimates
drop exp_fe_* imp_fe_*
qui tab exporter, gen(exp_fe_)
qui tab importer, gen(imp_fe_)

*offset imposes a constraint 
*ppml given new trade cost vector solve the MR

ppml trade exp_fe_* imp_fe_1-imp_fe_`=`NoC'-1', iter(30) noconst offset(t_ij_CFL_1) keep
predict trade_1_pred, mu
**********************************************
*Step 3.b: Construct `Conditional' GE Indexes*
**********************************************
forvalues i=1(1)`=`NoC'-1'{
qui replace exp_fe_`i'=exp_fe_`i'*exp(_b[exp_fe_`i'])
qui replace imp_fe_`i'=imp_fe_`i'*exp(_b[imp_fe_`i'])
}
qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])
egen all_exp_fes_1=rowtotal(exp_fe_1-exp_fe_`NoC')
egen all_imp_fes_1=rowtotal(imp_fe_1-imp_fe_`NoC') 
gen omr_CDL=output*expndr_deu/(all_exp_fes_1)
gen imr_CDL=expndr/(all_imp_fes_1*expndr_deu)
gen output_CDL=output
gen expndr_CDL=expndr
gen trade_CDL=(output_CDL*expndr_CDL*t_ij_CFL)/(imr_CDL*omr_CDL)
gen double exp_CDL=trade_CDL if exporter!=importer
bysort exporter: egen tot_exp_CDL=sum(exp_CDL)



*******************************************
*Step 4: Estimate `Full Endowment' Gravity*
*******************************************
*************************************
*Step 4.a: Prepare Initial Variables*
*************************************
*allow for endogenous size, allo from market clearing conditions
*instead of chaning the FE, use theory and update the trade flows
*estimate with the new value of trade
*construct new factory gate prices and 


gen expndr_1=expndr
gen double expndr_deu_1=expndr_deu
gen double temp1=all_exp_fes_0 if exporter==importer
bysort importer: egen double all_exp_fes_0_imp=mean(temp1)
gen double temp2=all_exp_fes_1 if exporter==importer
bysort importer: egen double all_exp_fes_1_imp=mean(temp2)

*FActory gate prices and changes
gen double p_FLL_exp_1=(all_exp_fes_1/all_exp_fes_0)^(1/(1-sigma))
gen double p_FLL_imp_1=(all_exp_fes_1_imp/all_exp_fes_0_imp)^(1/(1-sigma))
gen double p_FLL_exp_0=0
gen double imr_FLL_1=expndr_1/(all_imp_fes_1*expndr_deu_1)
gen double imr_FLL_ch_1=1
gen double omr_FLL_1=output*expndr_deu_1/(all_exp_fes_1)
gen double omr_FLL_ch_1=1
drop *temp*
******************************************************
*Step 4.b: Iterate to obtain `Full Endowment' indexes*
******************************************************
local i=3
local diff_all_exp_fes_sd=1
local diff_all_exp_fes_max=1
*I want to stop when the diferences in gate prices is zero
while (`diff_all_exp_fes_sd'>0.1) | (`diff_all_exp_fes_max'>0.1) {
		*******************************************************
		*i. Create new dependent variable and estimate gravity*
		*******************************************************
		*Gebnerating trade from theory from chaning prices
		gen double trade_`=`i'-1'=trade_`=`i'-2'_pred*p_FLL_exp_`=`i'-2'*p_FLL_imp_`=`i'-2'/(omr_FLL_ch_`=`i'-2'*imr_FLL_ch_`=`i'-2')
		drop exp_fe_* imp_fe_*
		qui tab exporter, gen (exp_fe_)
		qui tab importer, gen (imp_fe_)
		capture ppml trade_`=`i'-1' exp_fe_* imp_fe_*, offset(t_ij_CFL_1) noconst iter(30) 
		predict trade_`=`i'-1'_pred, mu
		*********************************
		*ii. Update output & expenditure*
		*********************************
		bysort exporter: egen double output_`=`i'-1'=total(trade_`=`i'-1'_pred)
		gen double expndr_temp_`=`i'-1'=phi*output_`=`i'-1' if exporter==importer
		bysort importer: egen double expndr_`=`i'-1'=mean(expndr_temp_`=`i'-1')
		gen double expndr_deu0_`=`i'-1'=expndr_`=`i'-1' if importer=="ZZZ"
		egen double expndr_deu_`=`i'-1'=mean(expndr_deu0_`=`i'-1')
		***********************************************
		*iii. Update factory-gate prices & resistances*
		***********************************************
		*Update MR like before
		
		forvalues j=1(1)`=`NoC'-1'{
		qui replace exp_fe_`j'=exp_fe_`j'*exp(_b[exp_fe_`j'])
		qui replace imp_fe_`j'=imp_fe_`j'*exp(_b[imp_fe_`j'])
		}
		qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])
		egen all_exp_fes_`=`i'-1'=rowtotal(exp_fe_1-exp_fe_`NoC')
		egen all_imp_fes_`=`i'-1'=rowtotal(imp_fe_1-imp_fe_`NoC') 
		gen double temp=all_exp_fes_`=`i'-1' if exporter==importer
		bysort importer: egen double all_exp_fes_`=`i'-1'_imp=mean(temp)
		gen double p_FLL_exp_`=`i'-1'=((all_exp_fes_`=`i'-1'/all_exp_fes_`=`i'-2')/(expndr_deu_`=`i'-1'/expndr_deu_`=`i'-2'))^(1/(1-sigma))
		gen double p_FLL_imp_`=`i'-1'=((all_exp_fes_`=`i'-1'_imp/all_exp_fes_`=`i'-2'_imp)/(expndr_deu_`=`i'-1'/expndr_deu_`=`i'-2'))^(1/(1-sigma))
		gen double omr_FLL_`=`i'-1'=(output_`=`i'-1'*expndr_deu_`=`i'-1')/all_exp_fes_`=`i'-1'
		gen double omr_FLL_ch_`=`i'-1'=omr_FLL_`=`i'-1'/omr_FLL_`=`i'-2'
		gen double imr_FLL_`=`i'-1'=expndr_`=`i'-1'/(all_imp_fes_`=`i'-1'*expndr_deu_`=`i'-1')
		gen double imr_FLL_ch_`=`i'-1'=imr_FLL_`=`i'-1'/imr_FLL_`=`i'-2'
		****************************************************************************
		*iv. Iterate Until Convergence: Until change in factory-gate prices is zero*
		****************************************************************************
		gen double diff_p_FLL_exp_`=`i'-1'=p_FLL_exp_`=`i'-2'-p_FLL_exp_`=`i'-3'
		sum diff_p_FLL_exp_`=`i'-1'
		local diff_all_exp_fes_sd=r(sd)
		local diff_all_exp_fes_max=abs(r(max))
		local i=`i'+1
		drop temp* 
}
*************************************************
*Step 4.c: Construct `Full Endowment' GE Indexes*
*************************************************


*Cllection importer FE
forvalues j=1(1)`=`NoC'-1'{
qui replace imp_fe_`j'=imp_fe_`j'*exp(_b[imp_fe_`j'])
}

*Full factory price change
gen double p_FLL=((all_exp_fes_`=`i'-2'/all_exp_fes_0)/(expndr_deu_`=`i'-2'/expndr_deu))^(1/(1-sigma))
gen output_FLL=p_FLL*output
gen double expndr_FLL_temp=phi*output_FLL if exporter==importer
bysort importer: egen double expndr_FLL=mean(expndr_FLL_temp)

*Outward, importer resistance
gen double omr_FLL=output_FLL*expndr_deu_`=`i'-2'/(all_exp_fes_`=`i'-2')
gen double imr_FLL=expndr_`=`i'-2'/(all_imp_fes_`=`i'-2'*expndr_deu_`=`i'-2')
gen trade_FLL=(output_FLL*expndr_FLL*t_ij_CFL)/(imr_FLL*omr_FLL)
gen double exp_FLL=trade_FLL if exporter!=importer
bysort exporter: egen tot_exp_FLL=sum(exp_FLL)
save full_static_all, replace

**************************************
*Step 5: Construct Percentage Changes*
**************************************
******************************
*a. On Export/Production Side*
******************************
*FActory gate prices where assumed to be 1

use full_static_all, clear
collapse omr_FLL omr_CDL omr_BLN p_FLL output* expndr* tot_exp* (firstnm) eu_j euro_j , by(exporter)
gen p_FLL_ch=(p_FLL-1)*100

*The model solves for the resistances of 1-sigma
gen omr_FLL_ch=(omr_FLL^(1/(1-sigma))-omr_BLN^(1/(1-sigma)))/omr_BLN^(1/(1-sigma))*100
gen omr_CDL_ch=(omr_CDL^(1/(1-sigma))-omr_BLN^(1/(1-sigma)))/omr_BLN^(1/(1-sigma))*100
gen tot_exp_FLL_ch=(tot_exp_FLL-tot_exp_BLN)/tot_exp_BLN*100
gen tot_exp_CDL_ch=(tot_exp_CDL-tot_exp_BLN)/tot_exp_BLN*100
rename exporter country
save prod_all, replace
*******************************
*b. On Import/Consumption Side*
*******************************
use full_static_all, clear
collapse imr_FLL imr_BLN imr_CDL (firstnm) eu_j euro_j , by(importer)
rename importer country
gen imr_FLL_ch=(imr_FLL^(1/(1-sigma))-imr_BLN^(1/(1-sigma)))/imr_BLN^(1/(1-sigma))*100
gen imr_CDL_ch=(imr_CDL^(1/(1-sigma))-imr_BLN^(1/(1-sigma)))/imr_BLN^(1/(1-sigma))*100
save cons_all, replace
*************************************
*c. Combine and Export to Tex/Excell*
*************************************

joinby country using prod_all
gen rGDP_BLN=output_BLN/(imr_BLN^(1/(1-sigma)))
gen rGDP_FLL=output_FLL/(imr_FLL^(1/(1-sigma)))
gen rGDP_FLL_ch=(rGDP_FLL-rGDP_BLN)/rGDP_BLN*100
keep country tot_exp_CDL_ch tot_exp_FLL_ch p_FLL_ch imr_FLL_ch omr_FLL_ch rGDP_FLL_ch eu_j euro_j 
order country tot_exp_CDL_ch tot_exp_FLL_ch p_FLL_ch imr_FLL_ch rGDP_FLL_ch

sort rGDP_FLL_ch

ge GDPchange=1+rGDP_FLL_ch/100

ge ConsPrch=1+imr_FLL_ch/100

ge ProPrch=1+p_FLL_ch/100

ge Exportch=1+tot_exp_FLL_ch/100

ameans GDPchange ProPrch ConsPrch Exportch
ge GDPAve=r(mean_g)


****For display and calculation pursopese****
generate pos = runiform(1,12)
recast int pos, force

ge n=_n

dataout, save(Table_4_EURO_CFL2_core) word tex replace dec(2)

drop if rGDP_FLL_ch>10

*****
ge euro_core=0

replace euro_core=1 if country=="DEU" 
replace euro_core=1 if country=="AUT" 
replace euro_core=1 if country=="BEL" 
replace euro_core=1 if country=="FIN" 
replace euro_core=1 if country=="FRA" 
replace euro_core=1 if country=="LUX" 
replace euro_core=1 if country=="NLD" 


ge euro_peri=0
replace euro_peri=1 if eu_j==1 & euro_core==0





ameans GDPchange
local GDPctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if eu_j==1 & euro_j==0
local GDPcoecd : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if euro_core==1
local GDPlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if eu_j==0 & euro_j==0
local GDPcrow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if euro_peri==1
local GDPchperi : display %04.2f round((r(mean_g)-1)*100,0.0005)

****


ameans  ProPrch 
local ProPrchctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if eu_j==1 & euro_j==0
local ProPrchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if euro_core==1 
local ProPrchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if eu_j==0 & euro_j==0
local ProPrchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if euro_peri==1
local ProPrchperi: display %04.2f round((r(mean_g)-1)*100,0.0005)


***

ameans ConsPrch
local ConsPrchctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if eu_j==1 & euro_j==0
local ConsPrchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if euro_core==1
local ConsPrchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if eu_j==0 & euro_j==0
local ConsPrchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if euro_peri==1
local ConsPrchperi: display %04.2f round((r(mean_g)-1)*100,0.0005)




ameans Exportch
local Exportchtot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if eu_j==1 & euro_j==0
local Exportchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if euro_core==1
local Exportchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if eu_j==0 & euro_j==0
local Exportchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if euro_peri==1
local Exportchperi: display %04.2f round((r(mean_g)-1)*100,0.0005)



#delimit ;
twoway scatter tot_exp_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter tot_exp_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter tot_exp_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Exports change") 
subtitle("(a) Exports Change ")
note("World Exports Change `Exportchtot'%" "ROW Exports Change `Exportchrow'%" "EU-non-EMU Exports Change `Exportchcoecd'%" "Core EMU Exports Change `Exportchlow'%" "Periphery EMU Exports Change `Exportchperi'%" )
legend(off) scheme(cleanplots)
;

#delimit cr

#delimit cr

graph save CF1_LOW_GDP1.gph, replace


#delimit ;
twoway scatter rGDP_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter rGDP_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter rGDP_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("GDP change") 
subtitle("(b) GDP Change ")
note("World GDP Change `GDPctot'%" "ROW GDP Change `GDPcrow'%" "EU-non-EMU GDP Change `GDPcoecd'%" "Core EMU GDP Change `GDPlow'%" "Periphery EMU GDP Change `GDPchperi'%"  )
legend(off) scheme(cleanplots)
;

#delimit cr

graph save CF1_LOW_GDP.gph, replace
*graph export "$main\CF1_LOW_GDP.pdf", as(pdf) replace

#delimit ;
twoway scatter imr_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter imr_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter imr_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Consumer prices change") 
subtitle("(c) Consumer prices ")
note("World Consumer prices Change `ConsPrchctot'%" "ROW Consumer prices Change `ConsPrchrow'%" "EU-non-EMU Consumer prices Change `ConsPrchcoecd'%" "Core EMU Consumer prices Change `ConsPrchlow'%" "Periphery EMU Consumer prices Change `ConsPrchperi'%" )
legend(off) scheme(cleanplots)
;
#delimit cr
graph save CF1_LOW_CP.gph, replace


#delimit ;
twoway scatter p_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter p_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter p_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Producer prices change /USA") 
subtitle("(d) Producer prices ")
note("World Producer prices Change `ProPrchctot'%" "ROW Producer prices Change `ProPrchrow'%" "EU-non-EMU Producer prices Change `ProPrchcoecd'%" "Core EMU Producer prices Change `ProPrchlow'%" "Periphery EMU Producer prices Change `ProPrchperi'%" )
legend(off) scheme(cleanplots)
;
#delimit cr

graph save CF1_LOW_PP.gph, replace


graph combine  CF1_LOW_GDP1.gph CF1_LOW_GDP.gph  CF1_LOW_CP.gph CF1_LOW_PP.gph, title("Counterfactual CFL 2: EURO only core")  scheme(cleanplots)

graph export "Figure 3. Counterfactual 2 EURO_core2.pdf", as(pdf) replace 
graph export "Figure 3. Counterfactual 2 EURO_core2.png", replace 
local datafiles: dir . files "CF*"
foreach datafile of local datafiles {
        erase "`datafile'"
}


******************************************
*Counterfactual 3. Table 5 and Figure 4
******************************************

use "emu_ge_data_rev.dta", replace




egen exporter_id=group(exporter)
egen importer_id =group(importer)
egen pair_id =group(importer exporter)




******************
**GLOBALIZATION***
******************

gen INTL_BRDR=1 if exporter!=importer
replace INTL_BRDR=0 if INTL_BRDR==.
forvalues i=1986(1)2017{
gen INTL_BRDR_`i'=1 if INTL_BRDR==1 & year==`i'
replace INTL_BRDR_`i'=0 if INTL_BRDR_`i'==.
}


egen trend=group(year)
ge EUtrend=EU2*trend
ge EUtrend2=EU2*trend*trend

ge custrict11_wo_emu= custrict11- CUEURO2

foreach var in CUEURO2 CUEURO1 EU2 custrict11_wo_emu rta_woEU2 EUtrend EUtrend2  {
replace `var'=0 if exporter==importer
}


ge LN_DIST =log(DIST) 
rename INTL_BRDR BRDR


****************
**EU variables***
****************

ge eu_i=0
ge eu_j=0



replace eu_i=1 if exporter=="AUT"
replace eu_i=1 if exporter=="BEL"
replace eu_i=1 if exporter=="BGR" & year>=2007
replace eu_i=1 if exporter=="HRV" & year>=2013
replace eu_i=1 if exporter=="CYP" & year>=2004
replace eu_i=1 if exporter=="CZE" & year>=2004
replace eu_i=1 if exporter=="DNK"
replace eu_i=1 if exporter=="EST" & year>=2004
replace eu_i=1 if exporter=="FIN" 
replace eu_i=1 if exporter=="FRA"
replace eu_i=1 if exporter=="DEU"
replace eu_i=1 if exporter=="GRC"

replace eu_i=1 if exporter=="IRL"
replace eu_i=1 if exporter=="HUN" & year>=2004
replace eu_i=1 if exporter=="ITA" 
replace eu_i=1 if exporter=="LVA" & year>=2004
replace eu_i=1 if exporter=="LTU" & year>=2004
replace eu_i=1 if exporter=="LUX"
replace eu_i=1 if exporter=="MLT" & year>=2004
replace eu_i=1 if exporter=="POL" & year>=2004
replace eu_i=1 if exporter=="NLD" 
replace eu_i=1 if exporter=="PRT"
replace eu_i=1 if exporter=="ROM" & year>=2007
replace eu_i=1 if exporter=="SVK" & year>=2004
replace eu_i=1 if exporter=="SVN" & year>=2004
replace eu_i=1 if exporter=="ESP"
replace eu_i=1 if exporter=="SWE" 
replace eu_i=1 if exporter=="GBR"
replace eu_i=1 if exporter=="ESP"

replace eu_j=1 if importer=="AUT"
replace eu_j=1 if importer=="BEL"
replace eu_j=1 if importer=="BGR" & year>=2007
replace eu_j=1 if importer=="HRV" & year>=2013
replace eu_j=1 if importer=="CYP" & year>=2004
replace eu_j=1 if importer=="CZE" & year>=2004
replace eu_j=1 if importer=="DNK"
replace eu_j=1 if importer=="EST" & year>=2004
replace eu_j=1 if importer=="FIN" 
replace eu_j=1 if importer=="FRA"
replace eu_j=1 if importer=="DEU"
replace eu_j=1 if importer=="GRC"

replace eu_j=1 if importer=="IRL"
replace eu_j=1 if importer=="HUN" & year>=2004
replace eu_j=1 if importer=="ITA" 
replace eu_j=1 if importer=="LVA" & year>=2004
replace eu_j=1 if importer=="LTU" & year>=2004
replace eu_j=1 if importer=="LUX"
replace eu_j=1 if importer=="MLT" & year>=2004
replace eu_j=1 if importer=="POL" & year>=2004
replace eu_j=1 if importer=="NLD" 
replace eu_j=1 if importer=="PRT"
replace eu_j=1 if importer=="ROM" & year>=2007
replace eu_j=1 if importer=="SVK" & year>=2004
replace eu_j=1 if importer=="SVN" & year>=2004
replace eu_j=1 if importer=="ESP"
replace eu_j=1 if importer=="SWE" 
replace eu_j=1 if importer=="GBR"
replace eu_j=1 if importer=="ESP"


ge EU=eu_j*eu_i*BRDR




**************
*EURO*********
**************




ge euro_i=0
ge euro_j=0

replace euro_i=1 if exporter=="DEU" & year>=1999
replace euro_i=1 if exporter=="AUT" & year>=1999
replace euro_i=1 if exporter=="BEL" & year>=1999
replace euro_i=1 if exporter=="FIN" & year>=1999
replace euro_i=1 if exporter=="FRA" & year>=1999
replace euro_i=1 if exporter=="IRL" & year>=1999
replace euro_i=1 if exporter=="ITA" & year>=1999
replace euro_i=1 if exporter=="LUX" & year>=1999
replace euro_i=1 if exporter=="NLD" & year>=1999
replace euro_i=1 if exporter=="PRT" & year>=1999
replace euro_i=1 if exporter=="ESP" & year>=1999
replace euro_i=1 if exporter=="GRC" & year>=2001

replace euro_j=1 if importer=="DEU" & year>=1999
replace euro_j=1 if importer=="AUT" & year>=1999
replace euro_j=1 if importer=="BEL" & year>=1999
replace euro_j=1 if importer=="FIN" & year>=1999
replace euro_j=1 if importer=="FRA" & year>=1999
replace euro_j=1 if importer=="IRL" & year>=1999
replace euro_j=1 if importer=="ITA" & year>=1999
replace euro_j=1 if importer=="LUX" & year>=1999
replace euro_j=1 if importer=="NLD" & year>=1999
replace euro_j=1 if importer=="PRT" & year>=1999
replace euro_j=1 if importer=="ESP" & year>=1999
replace euro_j=1 if importer=="GRC" & year>=2001

replace euro_j=1 if importer=="SVN" & year>=2007
replace euro_j=1 if importer=="CYP" & year>=2008
replace euro_j=1 if importer=="MLT" & year>=2008

replace euro_j=1 if importer=="SVK" & year>=2009
replace euro_j=1 if importer=="EST" & year>=2011
replace euro_j=1 if importer=="LVA" & year>=2014
replace euro_j=1 if importer=="LTU" & year>=2015

replace euro_i=1 if exporter=="SVN" & year>=2007
replace euro_i=1 if exporter=="CYP" & year>=2008
replace euro_i=1 if exporter=="MLT" & year>=2008

replace euro_i=1 if exporter=="SVK" & year>=2009
replace euro_i=1 if exporter=="EST" & year>=2011
replace euro_i=1 if exporter=="LVA" & year>=2014
replace euro_i=1 if exporter=="LTU" & year>=2015

ge EURO=euro_i*BRDR



eststo: ppmlhdfe trade  CUEURO2 CUEURO1 EU2 custrict11_wo_emu rta_woEU2 EUtrend EUtrend2  ///
, absorb(pair_id exporter_id#year importer_id#year ) cluster(pair_id )




ge b_emu2=_b[CUEURO2]
ge b_emu1=_b[CUEURO1]












keep if year==2016





drop if exporter=="MAC"
drop if importer=="MAC"


*******************************
*2. Create aggregate variables*
*******************************
*Market clearce condition: since we have internal trade this is total output

bysort exporter: egen output=sum(trade)
bysort importer: egen expndr=sum(trade)

****************************************
*3. Chose a country for reference group*
****************************************
replace exporter="ZZZ" if exporter=="USA"
replace importer="ZZZ" if importer=="USA"

*FE will be interptreated as expenditure.
gen expndr_deu0=expndr if importer=="ZZZ"

*Rescale all FE creating a variaBEL all values are DEU expenditure
egen expndr_deu=mean(expndr_deu0)
*************************
*4. Create Fixed Effects*
*************************
*MR from these FE

qui tab exporter, gen(exp_fe_)
qui tab importer, gen(imp_fe_)

qui tab exporter
local NoC=r(r)
sort imp_fe_`NoC'
*This is DEU by construction (that will be dropped)

******************************
*5. Set additional parameters*
****************************** 

*NoC: number of countries

gen double phi=expndr/output if exporter==importer
scalar sigma=7
qui tab exporter
local NoC=r(r)
save ge_ppml_data, replace

ppml trade LN_DIST CNTG BRDR  CUEURO2 CUEURO1  custrict11_wo_emu rta_woEU2   exp_fe_* imp_fe_1-imp_fe_`=`NoC'-1', iter(30) noconst 

predict trade_0_pred, mu






******************************************
*Step 1.a: Conscrut `Baseline' GE Indexes*
******************************************
forvalues i=1(1)`=`NoC'-1'{
qui replace exp_fe_`i'=exp_fe_`i'*exp(_b[exp_fe_`i']) 
qui replace imp_fe_`i'=imp_fe_`i'*exp(_b[imp_fe_`i'])
}
**** 2 variables with FE estimates and recover MR from these variables 
*Step 1b on the importer side, on the exporter side from 1 to 68
*Doping the same thing ouside the loop for the last FE (DEU
qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])


*Summing for
egen all_exp_fes_0=rowtotal(exp_fe_1-exp_fe_`NoC')
egen all_imp_fes_0=rowtotal(imp_fe_1-imp_fe_`NoC') 

gen t_ij_BLN=exp(_b[LN_DIST]*LN_DIST+_b[CNTG]*CNTG+_b[BRDR]*BRDR + b_emu2*CUEURO2 + b_emu1*CUEURO1 + _b[custrict11_wo_emu]*custrict11_wo_emu + _b[rta_woEU2]*rta_woEU2 )



*baseline 
gen output_BLN=output
gen expndr_BLN=expndr

*Constructing the MR terms ppml solved the non-linear system for us.
gen omr_BLN=output_BLN*expndr_deu/(all_exp_fes_0)
gen imr_BLN=expndr_BLN/(all_imp_fes_0*expndr_deu)

*data or data // predition vs prediction we need to be consistent
gen trade_BLN=(output_BLN*expndr_BLN*t_ij_BLN)/(imr_BLN*omr_BLN)


*Compate real GDP and total exports as the sum of exports 
*ojo, without internal trade
gen double exp_BLN=trade_BLN if exporter!=importer
bysort exporter: egen tot_exp_BLN=sum(exp_BLN)



****************************************
*Step 2: Define Counterfactual Scenario*
****************************************


gen t_ij_CFL=exp(_b[LN_DIST]*LN_DIST+_b[CNTG]*CNTG+_b[BRDR]*BRDR + _b[custrict11_wo_emu]*custrict11_wo_emu + _b[rta_woEU2]*rta_woEU2 )


gen t_ij_CFL_1=log(t_ij_CFL)


****************************************
*Step 3: Estimate `Conditional' Gravity*
****************************************
*Solve the model in counterfactual here size does not change.

*Dropping beacause replace them with their estimates
drop exp_fe_* imp_fe_*
qui tab exporter, gen(exp_fe_)
qui tab importer, gen(imp_fe_)

*offset imposes a constraint 
*ppml given new trade cost vector solve the MR

ppml trade exp_fe_* imp_fe_1-imp_fe_`=`NoC'-1', iter(30) noconst offset(t_ij_CFL_1) keep
predict trade_1_pred, mu
**********************************************
*Step 3.b: Construct `Conditional' GE Indexes*
**********************************************
forvalues i=1(1)`=`NoC'-1'{
qui replace exp_fe_`i'=exp_fe_`i'*exp(_b[exp_fe_`i'])
qui replace imp_fe_`i'=imp_fe_`i'*exp(_b[imp_fe_`i'])
}
qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])
egen all_exp_fes_1=rowtotal(exp_fe_1-exp_fe_`NoC')
egen all_imp_fes_1=rowtotal(imp_fe_1-imp_fe_`NoC') 
gen omr_CDL=output*expndr_deu/(all_exp_fes_1)
gen imr_CDL=expndr/(all_imp_fes_1*expndr_deu)
gen output_CDL=output
gen expndr_CDL=expndr
gen trade_CDL=(output_CDL*expndr_CDL*t_ij_CFL)/(imr_CDL*omr_CDL)
gen double exp_CDL=trade_CDL if exporter!=importer
bysort exporter: egen tot_exp_CDL=sum(exp_CDL)


*up to here we have solve in the conditional scenario

*******************************************
*Step 4: Estimate `Full Endowment' Gravity*
*******************************************
*************************************
*Step 4.a: Prepare Initial Variables*
*************************************
*allow for endogenous size, allo from market clearing conditions
*instead of chaning the FE, use theory and update the trade flows
*estimate with the new value of trade
*construct new factory gate prices and 


gen expndr_1=expndr
gen double expndr_deu_1=expndr_deu
gen double temp1=all_exp_fes_0 if exporter==importer
bysort importer: egen double all_exp_fes_0_imp=mean(temp1)
gen double temp2=all_exp_fes_1 if exporter==importer
bysort importer: egen double all_exp_fes_1_imp=mean(temp2)

*FActory gate prices and changes
gen double p_FLL_exp_1=(all_exp_fes_1/all_exp_fes_0)^(1/(1-sigma))
gen double p_FLL_imp_1=(all_exp_fes_1_imp/all_exp_fes_0_imp)^(1/(1-sigma))
gen double p_FLL_exp_0=0
gen double imr_FLL_1=expndr_1/(all_imp_fes_1*expndr_deu_1)
gen double imr_FLL_ch_1=1
gen double omr_FLL_1=output*expndr_deu_1/(all_exp_fes_1)
gen double omr_FLL_ch_1=1
drop *temp*
******************************************************
*Step 4.b: Iterate to obtain `Full Endowment' indexes*
******************************************************
local i=3
local diff_all_exp_fes_sd=1
local diff_all_exp_fes_max=1
*I want to stop when the diferences in gate prices is zero
while (`diff_all_exp_fes_sd'>0.1) | (`diff_all_exp_fes_max'>0.1) {
		*******************************************************
		*i. Create new dependent variable and estimate gravity*
		*******************************************************
		*Gebnerating trade from theory from chaning prices
		gen double trade_`=`i'-1'=trade_`=`i'-2'_pred*p_FLL_exp_`=`i'-2'*p_FLL_imp_`=`i'-2'/(omr_FLL_ch_`=`i'-2'*imr_FLL_ch_`=`i'-2')
		drop exp_fe_* imp_fe_*
		qui tab exporter, gen (exp_fe_)
		qui tab importer, gen (imp_fe_)
		capture ppml trade_`=`i'-1' exp_fe_* imp_fe_*, offset(t_ij_CFL_1) noconst iter(30) 
		predict trade_`=`i'-1'_pred, mu
		*********************************
		*ii. Update output & expenditure*
		*********************************
		bysort exporter: egen double output_`=`i'-1'=total(trade_`=`i'-1'_pred)
		gen double expndr_temp_`=`i'-1'=phi*output_`=`i'-1' if exporter==importer
		bysort importer: egen double expndr_`=`i'-1'=mean(expndr_temp_`=`i'-1')
		gen double expndr_deu0_`=`i'-1'=expndr_`=`i'-1' if importer=="ZZZ"
		egen double expndr_deu_`=`i'-1'=mean(expndr_deu0_`=`i'-1')
		***********************************************
		*iii. Update factory-gate prices & resistances*
		***********************************************
		*Update MR like before
		
		forvalues j=1(1)`=`NoC'-1'{
		qui replace exp_fe_`j'=exp_fe_`j'*exp(_b[exp_fe_`j'])
		qui replace imp_fe_`j'=imp_fe_`j'*exp(_b[imp_fe_`j'])
		}
		qui replace exp_fe_`NoC'=exp_fe_`NoC'*exp(_b[exp_fe_`NoC'])
		egen all_exp_fes_`=`i'-1'=rowtotal(exp_fe_1-exp_fe_`NoC')
		egen all_imp_fes_`=`i'-1'=rowtotal(imp_fe_1-imp_fe_`NoC') 
		gen double temp=all_exp_fes_`=`i'-1' if exporter==importer
		bysort importer: egen double all_exp_fes_`=`i'-1'_imp=mean(temp)
		gen double p_FLL_exp_`=`i'-1'=((all_exp_fes_`=`i'-1'/all_exp_fes_`=`i'-2')/(expndr_deu_`=`i'-1'/expndr_deu_`=`i'-2'))^(1/(1-sigma))
		gen double p_FLL_imp_`=`i'-1'=((all_exp_fes_`=`i'-1'_imp/all_exp_fes_`=`i'-2'_imp)/(expndr_deu_`=`i'-1'/expndr_deu_`=`i'-2'))^(1/(1-sigma))
		gen double omr_FLL_`=`i'-1'=(output_`=`i'-1'*expndr_deu_`=`i'-1')/all_exp_fes_`=`i'-1'
		gen double omr_FLL_ch_`=`i'-1'=omr_FLL_`=`i'-1'/omr_FLL_`=`i'-2'
		gen double imr_FLL_`=`i'-1'=expndr_`=`i'-1'/(all_imp_fes_`=`i'-1'*expndr_deu_`=`i'-1')
		gen double imr_FLL_ch_`=`i'-1'=imr_FLL_`=`i'-1'/imr_FLL_`=`i'-2'
		****************************************************************************
		*iv. Iterate Until Convergence: Until change in factory-gate prices is zero*
		****************************************************************************
		gen double diff_p_FLL_exp_`=`i'-1'=p_FLL_exp_`=`i'-2'-p_FLL_exp_`=`i'-3'
		sum diff_p_FLL_exp_`=`i'-1'
		local diff_all_exp_fes_sd=r(sd)
		local diff_all_exp_fes_max=abs(r(max))
		local i=`i'+1
		drop temp* 
}
*************************************************
*Step 4.c: Construct `Full Endowment' GE Indexes*
*************************************************


*Cllection importer FE
forvalues j=1(1)`=`NoC'-1'{
qui replace imp_fe_`j'=imp_fe_`j'*exp(_b[imp_fe_`j'])
}

*Full factory price change
gen double p_FLL=((all_exp_fes_`=`i'-2'/all_exp_fes_0)/(expndr_deu_`=`i'-2'/expndr_deu))^(1/(1-sigma))
gen output_FLL=p_FLL*output
gen double expndr_FLL_temp=phi*output_FLL if exporter==importer
bysort importer: egen double expndr_FLL=mean(expndr_FLL_temp)

*Outward, importer resistance
gen double omr_FLL=output_FLL*expndr_deu_`=`i'-2'/(all_exp_fes_`=`i'-2')
gen double imr_FLL=expndr_`=`i'-2'/(all_imp_fes_`=`i'-2'*expndr_deu_`=`i'-2')
gen trade_FLL=(output_FLL*expndr_FLL*t_ij_CFL)/(imr_FLL*omr_FLL)
gen double exp_FLL=trade_FLL if exporter!=importer
bysort exporter: egen tot_exp_FLL=sum(exp_FLL)
save full_static_all, replace

**************************************
*Step 5: Construct Percentage Changes*
**************************************
******************************
*a. On Export/Production Side*
******************************
*FActory gate prices where assumed to be 1

use full_static_all, clear
collapse omr_FLL omr_CDL omr_BLN p_FLL output* expndr* tot_exp* (firstnm) eu_j euro_j , by(exporter)
gen p_FLL_ch=(p_FLL-1)*100

*The model solves for the resistances of 1-sigma
gen omr_FLL_ch=(omr_FLL^(1/(1-sigma))-omr_BLN^(1/(1-sigma)))/omr_BLN^(1/(1-sigma))*100
gen omr_CDL_ch=(omr_CDL^(1/(1-sigma))-omr_BLN^(1/(1-sigma)))/omr_BLN^(1/(1-sigma))*100
gen tot_exp_FLL_ch=(tot_exp_FLL-tot_exp_BLN)/tot_exp_BLN*100
gen tot_exp_CDL_ch=(tot_exp_CDL-tot_exp_BLN)/tot_exp_BLN*100
rename exporter country
save prod_all, replace
*******************************
*b. On Import/Consumption Side*
*******************************
use full_static_all, clear
collapse imr_FLL imr_BLN imr_CDL (firstnm) eu_j euro_j , by(importer)
rename importer country
gen imr_FLL_ch=(imr_FLL^(1/(1-sigma))-imr_BLN^(1/(1-sigma)))/imr_BLN^(1/(1-sigma))*100
gen imr_CDL_ch=(imr_CDL^(1/(1-sigma))-imr_BLN^(1/(1-sigma)))/imr_BLN^(1/(1-sigma))*100
save cons_all, replace
*************************************
*c. Combine and Export to Tex/Excell*
*************************************

joinby country using prod_all
gen rGDP_BLN=output_BLN/(imr_BLN^(1/(1-sigma)))
gen rGDP_FLL=output_FLL/(imr_FLL^(1/(1-sigma)))
gen rGDP_FLL_ch=(rGDP_FLL-rGDP_BLN)/rGDP_BLN*100
keep country tot_exp_CDL_ch tot_exp_FLL_ch p_FLL_ch imr_FLL_ch omr_FLL_ch rGDP_FLL_ch eu_j euro_j 
order country tot_exp_CDL_ch tot_exp_FLL_ch p_FLL_ch imr_FLL_ch rGDP_FLL_ch

sort rGDP_FLL_ch

ge GDPchange=1+rGDP_FLL_ch/100

ge ConsPrch=1+imr_FLL_ch/100

ge ProPrch=1+p_FLL_ch/100

ge Exportch=1+tot_exp_FLL_ch/100

ameans GDPchange ProPrch ConsPrch Exportch
ge GDPAve=r(mean_g)


****For display and calculation pursopese****


*****

generate pos = runiform(1,12)
recast int pos, force

ge n=_n



ameans GDPchange
local GDPctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if eu_j==1 & euro_j==0
local GDPcoecd : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if euro_j==1 
local GDPlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans GDPchange if eu_j==0 & euro_j==0
local GDPcrow : display %04.2f round((r(mean_g)-1)*100,0.0005)


ameans  ProPrch 
local ProPrchctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if eu_j==1 & euro_j==0
local ProPrchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if euro_j==1 
local ProPrchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ProPrch if eu_j==0 & euro_j==0
local ProPrchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)


ameans ConsPrch
local ConsPrchctot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if eu_j==1 & euro_j==0
local ConsPrchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if euro_j==1 
local ConsPrchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans ConsPrch if eu_j==0 & euro_j==0
local ConsPrchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)


ameans Exportch
local Exportchtot: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if eu_j==1 & euro_j==0
local Exportchcoecd: display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if euro_j==1 
local Exportchlow : display %04.2f round((r(mean_g)-1)*100,0.0005)

ameans Exportch if eu_j==0 & euro_j==0
local Exportchrow: display %04.2f round((r(mean_g)-1)*100,0.0005)


dataout, save(Table5_CLF3_EURO_ONE) word tex replace dec(2)

drop if rGDP_FLL_ch>10
*drop if country=="CMR"



*twoway scatter p_FLL_ch cpiXBRDR_j, mlab( country) mlabs(tiny) mlabv(pos) || lfit p_FLL_ch cpiXBRDR_j, 


#delimit ;
twoway scatter tot_exp_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter tot_exp_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter tot_exp_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Exports change") 
subtitle("(a) Exports Change ")
note("World Exports Change `Exportchtot'%" "ROW Exports Change `Exportchrow'%" "EU-non-EMU Exports Change `Exportchcoecd'%" "EMU Exports Change `Exportchlow'%"  )
legend(off) scheme(cleanplots)
;

#delimit cr

#delimit cr

graph save CF1_LOW_GDP1.gph, replace
*graph export "$main\CF1_LOW_GDP1.pdf", as(pdf) replace

#delimit ;
twoway scatter rGDP_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter rGDP_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter rGDP_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("GDP change") 
subtitle("(b) GDP Change ")
note("World GDP Change `GDPctot'%" "ROW GDP Change `GDPcrow'%" "EU-non-EMU GDP Change `GDPcoecd'%" "EMU GDP Change `GDPlow'%"  )
legend(off) scheme(cleanplots)
;

#delimit cr

graph save CF1_LOW_GDP.gph, replace
*graph export "$main\CF1_LOW_GDP.pdf", as(pdf) replace

#delimit ;
twoway scatter imr_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter imr_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter imr_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Consumer prices change") 
subtitle("(c) Consumer prices ")
note("World Consumer prices Change `ConsPrchctot'%" "ROW Consumer prices Change `ConsPrchrow'%" "EU-non-EMU Consumer prices Change `ConsPrchcoecd'%" "EMU Consumer prices Change `ConsPrchlow'%" )
legend(off) scheme(cleanplots)
;
#delimit cr
graph save CF1_LOW_CP.gph, replace
*graph export "$main\CF1_LOW_CP.pdf", as(pdf) replace

#delimit ;
twoway scatter p_FLL_ch n if (eu_j==0 & euro_j==0), mlab( country) mlabs(tiny) mlabv(pos) 
|| scatter p_FLL_ch n if eu_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(maroon) mlabc(maroon)
|| scatter p_FLL_ch n if  euro_j==1, mlab( country) mlabs(tiny) mlabv(pos) mcolor(green) mlabc(green)
ytitle("Producer prices change /USA") 
subtitle("(d) Producer prices ")
note("World Producer prices Change `ProPrchctot'%" "ROW Producer prices Change `ProPrchrow'%" "EU-non-EMU Producer prices Change `ProPrchcoecd'%" "EMU Producer prices Change `ProPrchlow'%" )
legend(off) scheme(cleanplots)
;
#delimit cr

graph save CF1_LOW_PP.gph, replace

*graph export "$main\CF1_LOW_PP.pdf", as(pdf) replace

graph combine  CF1_LOW_GDP1.gph CF1_LOW_GDP.gph  CF1_LOW_CP.gph CF1_LOW_PP.gph, title("Counterfactual CF1: NO EURO")  scheme(cleanplots)

graph export "Figure 4. Counterfactual 3 EURO.pdf", as(pdf) replace
graph export "Figure 4. Counterfactual 3 EURO.png", replace


local datafiles: dir . files "CF*"
foreach datafile of local datafiles {
        erase "`datafile'"
}




log close
